@@ -1,7 +1,8 @@
 from pypop7.optimizers.cem.cem import CEM
 from pypop7.optimizers.cem.scem import SCEM
 from pypop7.optimizers.cem.dscem import DSCEM
+from pypop7.optimizers.cem.dcem import DCEM
 
 
 __all__ = [CEM,  # base (abstract) class
-           SCEM, DSCEM]
+           SCEM, DSCEM, DCEM]
